@@ -35,7 +35,6 @@ import subprocess
 import tempfile
 import shutil
 import re
-import sys
 
 from datetime import datetime
 
@@ -46,8 +45,8 @@ from sbackup.fs_backend import fam
 
 from sbackup.util.log import LogFactory
 from sbackup.util.structs import SBdict
-from sbackup.util.exceptions import SBException
 from sbackup.util import exceptions
+from sbackup.util.exceptions import SBException
 from sbackup.util import constants
 from sbackup.util import system
 from sbackup import util
@@ -248,6 +247,7 @@ def __prepare_common_opts(snapshot, targethandler, publish_progress, use_io_pipe
     _snpname = snapshot.getName()
     options = ["-cS", "--directory=%s" % _FOP.pathsep,
                "--ignore-failed-read",
+               "--no-check-device",
                "--blocking-factor", str(constants.TAR_BLOCKING_FACTOR),
                "--totals"
               ]
@@ -312,6 +312,11 @@ def __prepare_common_opts(snapshot, targethandler, publish_progress, use_io_pipe
         _checkpsize = _snpsize / _ncheckp
         _checkp = int(_checkpsize / constants.TAR_RECORDSIZE)
         if _checkp > 0:
+            # LP: #875634
+            # Sometimes the calculation of the space required goes badly wrong
+            # and we could end-up with _checkp=1 for 30GB to save, making tar
+            # VERY slow. Fix: set minimum value to 100
+            _checkp = max(100, _checkp)
             options.append("--checkpoint=%s" % _checkp)
             _progessf = util.get_resource_file(resource_name = "sbackup-progress")
             options.append('--checkpoint-action=exec=%s' % _progessf)
@@ -1050,9 +1055,9 @@ class SnapshotFile(object):
                 n += 1
             header += c
         try:
-            fd.close()
-        except:
-            LogFactory.getLogger().warn("error on closing the snarfile header after reading: " + str(sys.exc_info()[1]))
+            _FOP.close_stream(fd)
+        except exceptions.FileAlreadyClosedError, error:
+            log.LogFactory.getLogger().warn(_("File was already closed (ignored): %s") % error)
 
         return header
 
