@@ -1,6 +1,6 @@
 #   Simple Backup - configuration file handling
 #
-#   Copyright (c)2009-2010: Jean-Peer Lorenz <peer.loz@gmx.net>
+#   Copyright (c)2009-2010,2013: Jean-Peer Lorenz <peer.loz@gmx.net>
 #   Copyright (c)2007-2009: Ouattara Oumar Aziz <wattazoum@gmail.com>
 #
 #   This program is free software; you can redistribute it and/or modify
@@ -19,87 +19,11 @@
 #
 
 """
-Format of the configuration file used by SBackup:
+Configuration definition
 
-[general]
-mountdir = /mnt/sbackup
-target=/var/backup
-#target=ssh://user:pass@example.com/home/user/backup/
+For a description of sbackup's file format please have a look at the shipped
+example configuration file in sbackup/data/sbackup.conf.example.
 
-# Maximal interval between two full backups (in days)
-maxincrement = 21
-
-# Backup format:
-
-# none : use a tar - All files are stored in a non compressed tar archive
-# gzip : use a tar.gz - All files are stored in the files.tar.gz
-# bzip2 :use a tar.bz2 - All files are stored in the files.tar.bz2
-format = gzip
-# backup the links 
-backuplinks=1
-# follow symlinks
-followlinks=1
-
-# For the split functionality :
-# this should be an integer.
-# It represent the size in KiB (1024 B) of each archive
-# (splitsize <= 0: unlimited)
-splitsize = 0
-
-# Set the package manager command to backup the package list
-packagecmd = <whatever command that will be launched>
-
-[log]
-level = 20
-file = sbackup.log
-
-[report]
-from =
-to = 
-smtpserver =
-smtpport = 
-smtptls =
-
-
-[dirconfig]
-# In this section you describe, what directories to backup and what to skip 
-# More precise commands override wider ones, for example:
-# /var=1  # This means that the whole /var directory is to be backuped
-# /var/cache=0 # This means the /var/cache and its subdirectories are not
-#              # to  be backuped
-# In this case all /var, except /var/cache will be backuped
-# It works the othe way around too
-# by default nothing is backuped
-
-/etc/=1
-/home/=1
-/usr/local/=1
-/var/=1
-/var/cache/=0
-/var/tmp/=0
-/proc/=0
-/dev/=0
-/sys/=0
-/tmp/=0
-/var/tmp/=0
-
-[schedule]
-anacron = daily
-cron = 
-
-[exclude]
-
-# Comma-separated list of regular expressions to exclude from backup
-# use this to exclude certain types of files or directories
-#
-# Note: If any of these expressions matches within the whole pathname
-#    of the file, it will NOT be backuped. Keep this list as specific 
-#    and as short as possible.
-
-regex=\.mp3,\.avi,\.mpeg,\.mpg,\.mkv,\.ogg,\.ogm,\.tmp,/home/[^/]+?/\.thumbnails/,/home/[^/]+?/\.Trash,/home/[^/]+?/\..+/[cC]ache
-
-# Do not backup files bigger then this (in bytes)
-maxsize=100000000
 """
 
 
@@ -1333,6 +1257,10 @@ class ConfigurationFileHandler(object):
         if not os.path.exists(tempdir) :
             os.mkdir(tempdir)
 
+        #LP #785495: make the temp directory RWX only by owner
+        if (os.stat(tempdir).st_mode & 0777) != 0700:
+            os.chmod(tempdir,0700)
+            
         return tempdir
 
     def get_profilename(self, conffile):
@@ -1392,7 +1320,6 @@ class ConfigManagerStaticData(object):
                            'format'         : str,
                            'splitsize'     : int,
                            'purge'         : str,
-                           'run4others'     : int,
                            'followlinks'     : int,
                            'stop_if_no_target' : int,
                         'packagecmd'    : str},
@@ -1404,6 +1331,7 @@ class ConfigManagerStaticData(object):
      'dirconfig'    : { '*' : str },
      'exclude'         : { 'regex' : list, 'maxsize' : int },
      'places'         : { 'prefix' : str },
+     'hooks'        : {'pre-backup': list, 'post-backup': list },
      'schedule'     : {'anacron' : str , 'cron' : str }
     }
 
@@ -1658,20 +1586,20 @@ class _DefaultConfiguration(Configuration):
     def __init__(self):
         Configuration.__init__(self)
 
-        self._regex_excludes = "\.mp3$,\.avi$,\.mpeg$,\.mkv$,\.ogg$,\.iso$,"\
-                               "/home/[^/]+?/\.gvfs/,"\
-                               "/home/[^/]+?/\.thumbnails/,"\
-                               "/home/[^/]+?/\..+/[tT]rash/,"\
-                               "/home/[^/]+?/\..+/[cC]ache/,"\
+        self._regex_excludes = "^/home/[^/]+?/\.gvfs(/|$),"\
+                               "^/home/[^/]+?/\.thumbnails(/|$),"\
+                               "^/home/[^/]+?/\..+/[tT]rash(/|$),"\
+                               "^/home/[^/]+?/\.cache(/|$),"\
+                               "^/home/[^/]+?/\..+/[cC]ache(/|$),"\
+                               "^/home/[^/]+?/\..+/lock(/|$),"\
                                "~$"
-
         self._maxinc = 7
         self._cformat = 'none'
         self._follow_links = False
         self._splitsize = 0
         self._max_filesize = -1 #Bugfix LP #146618
 
-        self._loglevel = 20
+        self._loglevel = "20"  # set values as strings (LP #1159705)
         self._report_smtpfrom = Infos.SMTPFROM
 
         self._lockfile = "/var/lock/sbackup/sbackup.lock"
